==> mist_0.99.4.tar.gz: mist/inst/doc/mist_vignette.R <==
## ----eval = FALSE, warning=FALSE, message=FALSE-------------------------------
# # Install devtools if you don't have it installed already
# install.packages("devtools")
# 
# # Install mist from GitHub
# devtools::install_github("https://github.com/dxd429/mist")

## ----eval = FALSE, warning=FALSE, message=FALSE-------------------------------
# if (!requireNamespace("BiocManager", quietly = TRUE)) {
#     install.packages("BiocManager")
# }
# BiocManager::install("mist")

## ----eval=FALSE,warning=FALSE,message=FALSE-----------------------------------
# library(mist)
# vignette("mist")

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
library(mist)
library(SingleCellExperiment)
# Load sample scDNAm data
Dat_sce <- readRDS(system.file("extdata", "sampleData_sce.rds", package = "mist"))

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Estimate parameters for single-group
beta_sigma_list <- estiParamSingle(
    Dat_sce = Dat_sce,
    Dat_name = "Methy_level_group1",
    ptime_name = "pseudotime"
)

# Check the output
head(beta_sigma_list)

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Perform differential methylation analysis for the single-group
dm_results <- dmSingle(beta_sigma_list)

# View the top genomic features with drastic methylation changes
head(dm_results)

## ----eval=TRUE, fig.height=5, fig.width=8, message=FALSE, warning=FALSE, out.width='100%'----
# Produce scatterplot with fitted curve of a specific gene
plotGene(Dat_sce = Dat_sce,
         Dat_name = "Methy_level_group1",
         ptime_name = "pseudotime", 
         beta_sigma_list, 
         gene_name = "ENSMUSG00000000037")

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Load two-group scDNAm data
Dat_path <- readRDS(system.file("extdata", "sampleData_sce.rds", package = "mist"))

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Estimate parameters for both groups
beta_sigma_list_group <- estiParamTwo(
    Dat_sce = Dat_sce,
    Dat_name_g1 = "Methy_level_group1",
    Dat_name_g2 = "Methy_level_group2",
    ptime_name_g1 = "pseudotime",
    ptime_name_g2 = "pseudotime_g2"
)

# Check the output
names(beta_sigma_list_group)
head(beta_sigma_list_group[[1]], n = 3)
head(beta_sigma_list_group[[2]], n = 3)

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Perform DM analysis to compare the two groups
dm_results_two <- dmTwoGroups(beta_sigma_list_group)

# View the top genomic features with different temporal patterns between groups
head(dm_results_two)

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()

==> mist_0.99.5.tar.gz: mist/inst/doc/mist_vignette.R <==
## ----eval = FALSE, warning=FALSE, message=FALSE-------------------------------
# # Install devtools if you don't have it installed already
# install.packages("devtools")
# 
# # Install mist from GitHub
# devtools::install_github("https://github.com/dxd429/mist")

## ----eval = FALSE, warning=FALSE, message=FALSE-------------------------------
# if (!requireNamespace("BiocManager", quietly = TRUE)) {
#     install.packages("BiocManager")
# }
# BiocManager::install("mist")

## ----eval=FALSE,warning=FALSE,message=FALSE-----------------------------------
# library(mist)
# vignette("mist")

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
library(mist)
library(SingleCellExperiment)
# Load sample scDNAm data
Dat_sce <- readRDS(system.file("extdata", "small_sampleData_sce.rds", package = "mist"))

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Estimate parameters for single-group
beta_sigma_list <- estiParamSingle(
    Dat_sce = Dat_sce,
    Dat_name = "Methy_level_group1",
    ptime_name = "pseudotime"
)

# Check the output
head(beta_sigma_list)

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Perform differential methylation analysis for the single-group
dm_results <- dmSingle(beta_sigma_list)

# View the top genomic features with drastic methylation changes
head(dm_results)

## ----eval=TRUE, fig.height=5, fig.width=8, message=FALSE, warning=FALSE, out.width='100%'----
# Produce scatterplot with fitted curve of a specific gene
plotGene(Dat_sce = Dat_sce,
         Dat_name = "Methy_level_group1",
         ptime_name = "pseudotime", 
         beta_sigma_list, 
         gene_name = "ENSMUSG00000000037")

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Load two-group scDNAm data
Dat_path <- readRDS(system.file("extdata", "small_sampleData_sce.rds", package = "mist"))

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Estimate parameters for both groups
beta_sigma_list_group <- estiParamTwo(
    Dat_sce = Dat_sce,
    Dat_name_g1 = "Methy_level_group1",
    Dat_name_g2 = "Methy_level_group2",
    ptime_name_g1 = "pseudotime",
    ptime_name_g2 = "pseudotime_g2"
)

# Check the output
names(beta_sigma_list_group)
head(beta_sigma_list_group[[1]], n = 3)
head(beta_sigma_list_group[[2]], n = 3)

## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
# Perform DM analysis to compare the two groups
dm_results_two <- dmTwoGroups(beta_sigma_list_group)

# View the top genomic features with different temporal patterns between groups
head(dm_results_two)

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()
